@@ -6,11 +6,10 @@ from ctypes.wintypes import DWORD, ULONG
 
 from enum import Enum
 
-from src.tkdev4.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevEmail
-from src.tkdev4.devicon import Icon_Empty, Icon_Folder, Icon_TkinterDev
-from src.tkdev4.devresize import DevResize
-from src.tkdev4.devcore import DevAction
-from src.tkdev4.devtcl import (DevTray, ICON_APPLICATION, ICON_MODE_LOAD)
+from tkdev4.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevEmail
+from tkdev4.devicon import Icon_Empty, Icon_Folder, Icon_TkinterDev
+from tkdev4.devcore import DevAction
+from tkdev4.devtcl import (DevTray, ICON_APPLICATION, ICON_MODE_LOAD)
 
 try:
     from deprecated.sphinx import deprecated
@@ -241,27 +240,6 @@ class WindowComPositionAttributeData(Structure):
         ('SizeOfData', ULONG),
     ]
 
-
-def window_screenshot(window: tk.Tk, image_name: str = "Image.png"):
-    """
-    截取窗口图片
-    """
-    from tkcap import CAP
-    cap = CAP(window)
-    window.after(800, cap.capture(image_name))
-    return cap
-
-
-def resize_widget(widget: tk.Widget, size: int = 10):
-    """
-    使窗口可以被调整
-    """
-    try:
-        widget.after(1, lambda: DevResize(widget, size=size))
-    except tk.TclError:
-        pass
-
-
 def Error(text):
     try:
         from colorama import Fore
